<?php

namespace Drupal\wordfilter;

use Drupal\Core\Language\LanguageInterface;

/**
 * WordfilterLibrary class representing the library of useful Wordfilter functions.
 */
class WordfilterLibrary {

  /**
   * Provides filtering of words by given Wordfilter configuration.
   *
   * TODO Add further and more intelligent filtering algorithms.
   *      The algorithm should be selected at the Wordfilter configuration.
   *      Consider the use of an external web service.
   * @see https://www.drupal.org/node/2820128 (Default filtering process)
   * @see https://www.drupal.org/node/2820131 (Usage of different algorithms and services)
   *
   *
   * @param string $text
   *  The text to filter.
   * @param \Drupal\wordfilter\Entity\WordfilterConfigurationInterface $wordfilter_config
   *  The Wordfilter configuration to use during the filtering process.
   * @param string $langcode
   *  (Optional) The language code.
   *  This param has currently no impact on the
   *  filtering process itself, but may be used in future.
   *
   * @return string
   *   The filtered text.
   */
  static public function filterWords($text, $wordfilter_config, $langcode = LanguageInterface::LANGCODE_NOT_SPECIFIED) {
    $filter_words = $wordfilter_config->getFilterWords();
    $filter_pattern = '/\b(' . implode('|', $filter_words) . ')\b/i';
    $substitute = $wordfilter_config->getSubstitute();

    $text = preg_replace($filter_pattern, $substitute, $text);

    return $text;
  }
}